.. _api:

API
===

Top-level indices
-----------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


List of modules
---------------

.. toctree::
   :maxdepth: 2
   :caption: Core

   app
   arduino_
   buf
   config
   egu
   event
   pkt
   runctrl
   serial_
   timeline


.. toctree::
   :maxdepth: 2
   :caption: Utils

   silly
   profile


.. toctree::
   :maxdepth: 2
   :caption: GUI

   gui
